baldrick: a cunning plan for GitHub bots
========================================

Baldrick is a Python package that provides a framework to set up a GitHub bot
with minimal code and effort. If you run into any issues, have requests for
improvement, or would like to contribute, our GitHub repository is `here
<https://github.com/OpenAstronomy/baldrick>`_

.. toctree::
   :maxdepth: 1

   app.rst
   plugins.rst
   heroku.rst
   github.rst
   local.rst
   api.rst
